/* Generated by Nim Compiler v1.6.6 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <setjmp.h>
#include <windows.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
  #  define nimfr_(proc, file) \
      TFrame FR_; \
      FR_.procname = proc; FR_.filename = file; FR_.line = 0; FR_.len = 0; nimFrame(&FR_);

  #  define nimfrs_(proc, file, slots, length) \
      struct {TFrame* prev;NCSTRING procname;NI line;NCSTRING filename; NI len; VarSlot s[slots];} FR_; \
      FR_.procname = proc; FR_.filename = file; FR_.line = 0; FR_.len = length; nimFrame((TFrame*)&FR_);

  #  define nimln_(n, file) \
      FR_.line = n; FR_.filename = file;
  typedef struct tyObject_PyModuleDesc__gBC8z6Ez5xj3dXoP0ylCRA tyObject_PyModuleDesc__gBC8z6Ez5xj3dXoP0ylCRA;
typedef struct tySequence__E2XyP5e7Jr9aMpJMjdz5Tkg tySequence__E2XyP5e7Jr9aMpJMjdz5Tkg;
typedef struct tySequence__gorEUsBaLXWko3ZkxE9cpKw tySequence__gorEUsBaLXWko3ZkxE9cpKw;
typedef struct tySequence__xxWWYOndkW9adiM61bZkvsg tySequence__xxWWYOndkW9adiM61bZkvsg;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct Exception Exception;
typedef struct RootObj RootObj;
typedef struct tySequence__uB9b75OUPRENsBAu4AnoePA tySequence__uB9b75OUPRENsBAu4AnoePA;
typedef struct TSafePoint TSafePoint;
typedef struct tyObject_CatchableError__qrLSDoe2oBoAqNtJ9badtnA tyObject_CatchableError__qrLSDoe2oBoAqNtJ9badtnA;
typedef struct tyObject_PyLibcolonObjectType___bTw708kK89b8Vj9cmSu9a4zig tyObject_PyLibcolonObjectType___bTw708kK89b8Vj9cmSu9a4zig;
typedef struct tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g;
typedef struct tyObject_RawPyBuffer__0qyRdSZKtLACJ1u4qMMP2w tyObject_RawPyBuffer__0qyRdSZKtLACJ1u4qMMP2w;
typedef struct tyObject_Complex__zWadV1X9aMO7qS9bsQFB0JFA tyObject_Complex__zWadV1X9aMO7qS9bsQFB0JFA;
typedef struct tyObject_PyMethodDef__9aWi1PsmvCuTKIYDHHnhfcw tyObject_PyMethodDef__9aWi1PsmvCuTKIYDHHnhfcw;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tyObject_PyTypeDesc__BKCcJxogshNojOoN23Qfbg tyObject_PyTypeDesc__BKCcJxogshNojOoN23Qfbg;
typedef struct tyObject_PyIteratorDesc__3Lh9c29bpC2Iomkl9cQO9cGqEw tyObject_PyIteratorDesc__3Lh9c29bpC2Iomkl9cQO9cGqEw;
typedef struct tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA;
struct tyObject_PyModuleDesc__gBC8z6Ez5xj3dXoP0ylCRA {
NCSTRING name;
NCSTRING doc;
tySequence__E2XyP5e7Jr9aMpJMjdz5Tkg* methods;
tySequence__gorEUsBaLXWko3ZkxE9cpKw* types;
tySequence__xxWWYOndkW9adiM61bZkvsg* iterators;
};
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef N_NIMCALL_PTR(void, tyProc__T4eqaYlFJYZUv9aG9b1TV0bQ) (void);
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
typedef N_CDECL_PTR(void*, tyProc__uQWqJp3WAx8fOY1h9aCwjIg) (void* s, void* a, void* k);
typedef N_NIMCALL_PTR(void*, tyProc__iv6n7tcGawU401muvntJ9cA) (void* aX60gensym5_, void* kwgX60gensym5_);
typedef NCSTRING tyArray__NmEsK2qSxmxyFA4fWeYieg[1];
struct RootObj {
TNimType* m_type;
};
struct Exception {
  RootObj Sup;
Exception* parent;
NCSTRING name;
NimStringDesc* message;
tySequence__uB9b75OUPRENsBAu4AnoePA* trace;
Exception* up;
};
struct TSafePoint {
TSafePoint* prev;
NI status;
jmp_buf context;
};
typedef N_CDECL_PTR(void*, tyProc__SsjMo29bx9bP5kwe2xgM3Scg) (NCSTRING f, ...);
typedef N_CDECL_PTR(void*, tyProc__4wJmT85lsn175X0dPNQv7w) (NI sz);
typedef N_CDECL_PTR(NI, tyProc__YRQqZC12s3573tRGP8MV3g) (void* f);
typedef N_CDECL_PTR(void*, tyProc__oPIasAghCTvCKmvkMeB1xQ) (void* f, NI i);
typedef N_CDECL_PTR(int, tyProc__6slETyyIDJuDOSqkO0hUXA) (void* f, NI i, void* v);
typedef N_CDECL_PTR(int, tyProc__tgpXIILGoVcO9bvYnz9azTVQ) (tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* f);
typedef N_CDECL_PTR(void*, tyProc__eYT4U6bGFqFBUxk9b15mfOA) (tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* f, void* a, void* b);
typedef N_CDECL_PTR(int, tyProc__T08W9bgbY4bOv2q64h6irpw) (void* m, NCSTRING n, void* o);
typedef N_CDECL_PTR(int, tyProc__fbYpjfe38x3ujjAmVRbI1Q) (void* o);
typedef N_CDECL_PTR(void*, tyProc__YezmFzxOOyM9cb11Eoq1Elg) (void* o, NCSTRING name);
typedef N_CDECL_PTR(void*, tyProc__jvPpjMAkI9bwM1B9apOphnlA) (void* o);
typedef N_CDECL_PTR(void*, tyProc__VQ1ysQk017myXMGb79cPTVw) (void* o, void* k);
typedef N_CDECL_PTR(int, tyProc__7LMjBc4zOHVIsNdulNv7QQ) (void* o, void* k, void* v);
typedef N_CDECL_PTR(int, tyProc__eoRP3F9aLT3mtHj6OkcMSyQ) (void* a, void* b, int op);
typedef N_CDECL_PTR(int, tyProc__8hR9arLDkUs9ag3Pt9bWtjfsg) (void* o, tyObject_RawPyBuffer__0qyRdSZKtLACJ1u4qMMP2w* b, int flags);
typedef N_CDECL_PTR(void, tyProc__vFvpnKOere9bRFN9czzMRlTA) (tyObject_RawPyBuffer__0qyRdSZKtLACJ1u4qMMP2w* b);
typedef N_CDECL_PTR(void*, tyProc__BZ6N5NNdHcK05FTDxQbEWw) (NCSTRING name, void* base, void* dict);
typedef N_CDECL_PTR(NI64, tyProc__mIlNZ9aGaphVJCyIIofK8mg) (void* l);
typedef N_CDECL_PTR(NU64, tyProc__9b5I9aMvpc2qfvARBMMx9blAg) (void* l);
typedef N_CDECL_PTR(double, tyProc__2su9b9chqHYibM7sMkbSaSkA) (void* l);
typedef N_CDECL_PTR(void*, tyProc__RKlUmjvtmKGnc01PbvZaRQ) (long v);
typedef N_CDECL_PTR(int, tyProc__i2exZ7Vtp648U9crOFcq9beQ) (tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* t1, tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* t2);
struct tyObject_Complex__zWadV1X9aMO7qS9bsQFB0JFA {
NF re;
NF im;
};
typedef N_CDECL_PTR(tyObject_Complex__zWadV1X9aMO7qS9bsQFB0JFA, tyProc__N1A5ZvDSgO9c9aRXmVqfn9bAw) (void* op);
typedef N_CDECL_PTR(void*, tyProc__6esIxH9aNBn9aNzK4x86GkYw) (NIM_CHAR* s, NI len);
typedef N_CDECL_PTR(int, tyProc__3FKLKFzOaK7FD6dRLWM6Jw) (void* o, NIM_CHAR** s, NI* len);
typedef N_CDECL_PTR(void*, tyProc__YDKrw1adv61oVQkQhbYyaA) (NCSTRING s);
typedef N_CDECL_PTR(int, tyProc__B2MjSeo07a72ynTQRVYFKw) (void* o, NCSTRING s);
typedef N_CDECL_PTR(NCSTRING, tyProc__p1X2BwWx9a3wsChhykvf29aA) (void* o);
typedef N_CDECL_PTR(void*, tyProc__NzboHqZVJcbdtVGYrOosXQ) (void);
typedef N_CDECL_PTR(int, tyProc__MTei9bsKjha0o1cISO9aLMDg) (void* o, void* k);
typedef N_NIMCALL_PTR(void, tyProc__4SVlZZPmetqBimNsH9cHcOA) (void* o);
typedef N_CDECL_PTR(void, tyProc__ln4kdL5W9bbX4a1xl8nnVXQ) (void);
typedef N_CDECL_PTR(void, tyProc__WYY8i0I79agBofnUcEGCfig) (void* o, NCSTRING s);
typedef N_CDECL_PTR(void, tyProc__32w2ZypAyMWuajvi2Jt79cg) (void* o);
typedef N_CDECL_PTR(void*, tyProc__jcEovQ2rZUNUsYxohT50Ug) (void* p, NCSTRING name, tyProc__32w2ZypAyMWuajvi2Jt79cg destr);
typedef N_CDECL_PTR(void*, tyProc__9b2qzlf3LCKK0JvThQT1atg) (tyObject_PyMethodDef__9aWi1PsmvCuTKIYDHHnhfcw* md, void* self, void* module);
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
NI Field0;
NI Field1;
NI Field2;
};
typedef N_CDECL_PTR(void, tyProc__U0oVFt576Ze44Q9a3eZc5wg) (void** ptype, void** pvalue, void** ptraceback);
struct tyObject_PyLibcolonObjectType___bTw708kK89b8Vj9cmSu9a4zig {
void* module;
tyProc__SsjMo29bx9bP5kwe2xgM3Scg Py_BuildValue;
tyProc__4wJmT85lsn175X0dPNQv7w PyTuple_New;
tyProc__YRQqZC12s3573tRGP8MV3g PyTuple_Size;
tyProc__oPIasAghCTvCKmvkMeB1xQ PyTuple_GetItem;
tyProc__6slETyyIDJuDOSqkO0hUXA PyTuple_SetItem;
void* Py_None;
tyProc__tgpXIILGoVcO9bvYnz9azTVQ PyType_Ready;
tyProc__eYT4U6bGFqFBUxk9b15mfOA PyType_GenericNew;
tyProc__T08W9bgbY4bOv2q64h6irpw PyModule_AddObject;
tyProc__4wJmT85lsn175X0dPNQv7w PyList_New;
tyProc__YRQqZC12s3573tRGP8MV3g PyList_Size;
tyProc__oPIasAghCTvCKmvkMeB1xQ PyList_GetItem;
tyProc__6slETyyIDJuDOSqkO0hUXA PyList_SetItem;
tyProc__uQWqJp3WAx8fOY1h9aCwjIg PyObject_Call;
tyProc__fbYpjfe38x3ujjAmVRbI1Q PyObject_IsTrue;
tyProc__YezmFzxOOyM9cb11Eoq1Elg PyObject_GetAttrString;
tyProc__T08W9bgbY4bOv2q64h6irpw PyObject_SetAttrString;
tyProc__jvPpjMAkI9bwM1B9apOphnlA PyObject_Dir;
tyProc__jvPpjMAkI9bwM1B9apOphnlA PyObject_Str;
tyProc__jvPpjMAkI9bwM1B9apOphnlA PyObject_GetIter;
tyProc__VQ1ysQk017myXMGb79cPTVw PyObject_GetItem;
tyProc__7LMjBc4zOHVIsNdulNv7QQ PyObject_SetItem;
tyProc__eoRP3F9aLT3mtHj6OkcMSyQ PyObject_RichCompareBool;
tyProc__8hR9arLDkUs9ag3Pt9bWtjfsg PyObject_GetBuffer;
tyProc__vFvpnKOere9bRFN9czzMRlTA PyBuffer_Release;
tyProc__BZ6N5NNdHcK05FTDxQbEWw PyErr_NewException;
tyProc__jvPpjMAkI9bwM1B9apOphnlA PyIter_Next;
tyProc__jvPpjMAkI9bwM1B9apOphnlA PyNumber_Long;
tyProc__mIlNZ9aGaphVJCyIIofK8mg PyLong_AsLongLong;
tyProc__9b5I9aMvpc2qfvARBMMx9blAg PyLong_AsUnsignedLongLong;
tyProc__2su9b9chqHYibM7sMkbSaSkA PyFloat_AsDouble;
tyProc__RKlUmjvtmKGnc01PbvZaRQ PyBool_FromLong;
tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* PyBool_Type;
tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* PyFloat_Type;
tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* PyComplex_Type;
tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* PyCapsule_Type;
tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* PyTuple_Type;
tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* PyList_Type;
tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* PyBytes_Type;
tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* PyUnicode_Type;
tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* PySuper_Type;
tyProc__i2exZ7Vtp648U9crOFcq9beQ PyType_IsSubtype;
tyProc__N1A5ZvDSgO9c9aRXmVqfn9bAw PyComplex_AsCComplex;
tyProc__2su9b9chqHYibM7sMkbSaSkA PyComplex_RealAsDouble;
tyProc__2su9b9chqHYibM7sMkbSaSkA PyComplex_ImagAsDouble;
tyProc__jvPpjMAkI9bwM1B9apOphnlA PyUnicode_AsUTF8String;
tyProc__6esIxH9aNBn9aNzK4x86GkYw PyBytes_FromStringAndSize;
tyProc__3FKLKFzOaK7FD6dRLWM6Jw PyBytes_AsStringAndSize;
tyProc__YDKrw1adv61oVQkQhbYyaA PyUnicode_FromString;
tyProc__B2MjSeo07a72ynTQRVYFKw PyUnicode_CompareWithASCIIString;
tyProc__p1X2BwWx9a3wsChhykvf29aA PyString_AsString;
tyObject_PyTypeObject3Obj__cRsC9bGvH9bX6A9aVx8UB6I5g* PyDict_Type;
tyProc__NzboHqZVJcbdtVGYrOosXQ PyDict_New;
tyProc__YRQqZC12s3573tRGP8MV3g PyDict_Size;
tyProc__YezmFzxOOyM9cb11Eoq1Elg PyDict_GetItemString;
tyProc__T08W9bgbY4bOv2q64h6irpw PyDict_SetItemString;
tyProc__VQ1ysQk017myXMGb79cPTVw PyDict_GetItem;
tyProc__7LMjBc4zOHVIsNdulNv7QQ PyDict_SetItem;
tyProc__jvPpjMAkI9bwM1B9apOphnlA PyDict_Keys;
tyProc__jvPpjMAkI9bwM1B9apOphnlA PyDict_Values;
tyProc__MTei9bsKjha0o1cISO9aLMDg PyDict_Contains;
tyProc__4SVlZZPmetqBimNsH9cHcOA PyDealloc;
tyProc__ln4kdL5W9bbX4a1xl8nnVXQ PyErr_Clear;
tyProc__WYY8i0I79agBofnUcEGCfig PyErr_SetString;
tyProc__NzboHqZVJcbdtVGYrOosXQ PyErr_Occurred;
void* PyExc_TypeError;
tyProc__jcEovQ2rZUNUsYxohT50Ug PyCapsule_New;
tyProc__YezmFzxOOyM9cb11Eoq1Elg PyCapsule_GetPointer;
tyProc__YDKrw1adv61oVQkQhbYyaA PyImport_ImportModule;
tyProc__NzboHqZVJcbdtVGYrOosXQ PyEval_GetBuiltins;
tyProc__NzboHqZVJcbdtVGYrOosXQ PyEval_GetGlobals;
tyProc__NzboHqZVJcbdtVGYrOosXQ PyEval_GetLocals;
tyProc__9b2qzlf3LCKK0JvThQT1atg PyCFunction_NewEx;
tyTuple__47w2DboNEPf69aPgubZdd7Q pythonVersion;
tyProc__ln4kdL5W9bbX4a1xl8nnVXQ PyErr_Print;
tyProc__U0oVFt576Ze44Q9a3eZc5wg PyErr_Fetch;
tyProc__U0oVFt576Ze44Q9a3eZc5wg PyErr_NormalizeException;
tyProc__MTei9bsKjha0o1cISO9aLMDg PyErr_GivenExceptionMatches;
void* PyExc_BaseException;
void* PyExc_Exception;
void* PyExc_ArithmeticError;
void* PyExc_FloatingPointError;
void* PyExc_OverflowError;
void* PyExc_ZeroDivisionError;
void* PyExc_AssertionError;
void* PyExc_OSError;
void* PyExc_IOError;
void* PyExc_ValueError;
void* PyExc_EOFError;
void* PyExc_MemoryError;
void* PyExc_IndexError;
void* PyExc_KeyError;
void* NimPyException;
};
struct tyObject_CatchableError__qrLSDoe2oBoAqNtJ9badtnA {
  Exception Sup;
};
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
struct tyObject_PyMethodDef__9aWi1PsmvCuTKIYDHHnhfcw {
NCSTRING ml_name;
tyProc__uQWqJp3WAx8fOY1h9aCwjIg ml_meth;
int ml_flags;
NCSTRING ml_doc;
};
struct tyObject_PyIteratorDesc__3Lh9c29bpC2Iomkl9cQO9cGqEw {
NCSTRING name;
NCSTRING doc;
tyProc__eYT4U6bGFqFBUxk9b15mfOA newFunc;
};
struct tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA {
NCSTRING procname;
NI line;
NCSTRING filename;
};
struct tySequence__E2XyP5e7Jr9aMpJMjdz5Tkg {
  TGenericSeq Sup;
  tyObject_PyMethodDef__9aWi1PsmvCuTKIYDHHnhfcw data[SEQ_DECL_SIZE];
};
struct tySequence__gorEUsBaLXWko3ZkxE9cpKw {
  TGenericSeq Sup;
  tyObject_PyTypeDesc__BKCcJxogshNojOoN23Qfbg* data[SEQ_DECL_SIZE];
};
struct tySequence__xxWWYOndkW9adiM61bZkvsg {
  TGenericSeq Sup;
  tyObject_PyIteratorDesc__3Lh9c29bpC2Iomkl9cQO9cGqEw data[SEQ_DECL_SIZE];
};
struct tySequence__uB9b75OUPRENsBAu4AnoePA {
  TGenericSeq Sup;
  tyObject_StackTraceEntry__oLyohQ7O2XOvGnflOss8EA data[SEQ_DECL_SIZE];
};
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, TM__A82ybR1KJ9a3GOSp2XtOMmw_2)(void);
N_LIB_PRIVATE N_NIMCALL(void, nimRegisterGlobalMarker)(tyProc__T4eqaYlFJYZUv9aG9b1TV0bQ markerProc);
N_LIB_PRIVATE N_NIMCALL(void, initPythonModuleDesc__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_289)(tyObject_PyModuleDesc__gBC8z6Ez5xj3dXoP0ylCRA* m, NCSTRING name, NCSTRING doc);
N_LIB_EXPORT N_CDECL(void, initfast)(void);
N_LIB_PRIVATE N_NIMCALL(void, initModule2__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_350)(tyObject_PyModuleDesc__gBC8z6Ez5xj3dXoP0ylCRA* m);
N_LIB_EXPORT N_CDECL(void*, PyInit_fast)(void);
N_LIB_PRIVATE N_NIMCALL(void*, initModule3__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_491)(tyObject_PyModuleDesc__gBC8z6Ez5xj3dXoP0ylCRA* m);
N_LIB_PRIVATE N_NIMCALL(tyObject_PyModuleDesc__gBC8z6Ez5xj3dXoP0ylCRA*, _nimpyModuleDesc_fast)(void);
N_LIB_PRIVATE N_NIMCALL(void, registerExportedModule__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_308)(NimStringDesc* name, void* initAddr2, void* initAddr3);
N_NIMCALL(tyObject_PyModuleDesc__gBC8z6Ez5xj3dXoP0ylCRA*, _nimpyModuleDesc_fast)(void);
N_LIB_PRIVATE N_NIMCALL(void, registerMethod__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_63)(NCSTRING name, NCSTRING doc, tyProc__uQWqJp3WAx8fOY1h9aCwjIg f);
N_LIB_PRIVATE N_CDECL(void*, fibPy_wrapper__fast_45)(void* selfX60gensym5_, void* args, void* kwargs);
static N_INLINE(void, updateStackBottom__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_322)(void);
N_LIB_PRIVATE N_NOINLINE(void, nimGC_setStackBottom)(void* theStackBottom);
static N_INLINE(void, nimFrame)(TFrame* s);
N_LIB_PRIVATE N_NOINLINE(void, callDepthLimitReached__system_2999)(void);
static N_INLINE(void, popFrame)(void);
N_LIB_PRIVATE N_NIMCALL(void*, noinline__fast_82)(void* args, void* kwargs);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, verifyArgs__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_678)(void* argTuple, void* kwargsDict, NI argsLen, NI argsLenReq, NCSTRING* argNames, NI argNamesLen_0, NimStringDesc* funcName);
static N_INLINE(void, pushSafePoint)(TSafePoint* s);
N_LIB_PRIVATE N_NIMCALL(void, parseArg__fast_89)(void* argTuple, void* kwargsDict, NI argIdx, NCSTRING argName, NI* result);
static N_INLINE(void, popSafePoint)(void);
static N_INLINE(TFrame*, getFrame)(void);
static N_INLINE(void, setFrame)(TFrame* s);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isObj)(TNimType* obj, TNimType* subclass);
static N_INLINE(Exception*, nimBorrowCurrentException)(void);
static N_INLINE(Exception*, getCurrentException)(void);
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringDesc* s);
static N_INLINE(void, popCurrentException)(void);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5392)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__system_5354)(void* usr);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(void, decRef__system_5399)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5397)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5348)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NIMCALL(void, reraiseException)(void);
N_LIB_PRIVATE N_NIMCALL(void*, nimValueOrVoidToPy__fast_102)(NI v);
N_LIB_PRIVATE N_NIMCALL(NI, fib__fast_75)(NI n);
N_LIB_PRIVATE N_NOINLINE(void, raiseOverflow)(void);
N_LIB_PRIVATE N_NIMCALL(void*, pythonException__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_324)(Exception* e);
static N_INLINE(void, initStackBottomWith)(void* locals);
N_LIB_PRIVATE N_NIMCALL(void, stdlib_ioInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, systemDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, systemInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, stdlib_winleanDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, stdlib_winleanInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, stdlib_timesDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, stdlib_timesInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, stdlib_osDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, stdlib_osInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, nimpy_py_typesDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, nimpy_py_libDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, nimpy_py_libInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, nimpy_nimpyDatInit000)(void);
N_LIB_PRIVATE N_NIMCALL(void, NimMainModule)(void);
extern TNimType NTIpymoduledesc__gBC8z6Ez5xj3dXoP0ylCRA_;
STRING_LITERAL(TM__A82ybR1KJ9a3GOSp2XtOMmw_3, "fast", 4);
static NIM_CONST tyArray__NmEsK2qSxmxyFA4fWeYieg TM__A82ybR1KJ9a3GOSp2XtOMmw_4 = {"n"}
;
STRING_LITERAL(TM__A82ybR1KJ9a3GOSp2XtOMmw_5, "fib", 3);
extern TNimType NTIcatchableerror__qrLSDoe2oBoAqNtJ9badtnA_;
extern TNimType NTIexception__XEycrCsme5C8CVWAYEcdBQ_;
N_LIB_PRIVATE tyObject_PyModuleDesc__gBC8z6Ez5xj3dXoP0ylCRA moduleDescX60gensym3___fast_35;
extern tyObject_PyModuleDesc__gBC8z6Ez5xj3dXoP0ylCRA* curModuleDef__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_53;
extern TFrame* framePtr__system_2566;
extern TFrame* framePtr__system_2566;
extern TFrame* framePtr__system_2566;
extern TFrame* framePtr__system_2566;
extern TFrame* framePtr__system_2566;
extern TFrame* framePtr__system_2566;
extern TSafePoint* excHandler__system_2567;
extern TSafePoint* excHandler__system_2567;
extern TSafePoint* excHandler__system_2567;
extern TSafePoint* excHandler__system_2567;
extern TFrame* framePtr__system_2566;
extern TFrame* framePtr__system_2566;
extern Exception* currException__system_2568;
extern Exception* currException__system_2568;
extern tyObject_PyLibcolonObjectType___bTw708kK89b8Vj9cmSu9a4zig* pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279;
extern Exception* currException__system_2568;
extern Exception* currException__system_2568;
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__system_5301;
static N_NIMCALL(void, TM__A82ybR1KJ9a3GOSp2XtOMmw_2)(void) {
	nimGCvisit((void*)moduleDescX60gensym3___fast_35.methods, 0);
	nimGCvisit((void*)moduleDescX60gensym3___fast_35.types, 0);
	nimGCvisit((void*)moduleDescX60gensym3___fast_35.iterators, 0);
}
N_LIB_EXPORT N_CDECL(void, initfast)(void) {
	initModule2__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_350((&moduleDescX60gensym3___fast_35));
}
N_LIB_EXPORT N_CDECL(void*, PyInit_fast)(void) {
	void* result;
	result = (void*)0;
	result = initModule3__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_491((&moduleDescX60gensym3___fast_35));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_PyModuleDesc__gBC8z6Ez5xj3dXoP0ylCRA*, _nimpyModuleDesc_fast)(void) {
	tyObject_PyModuleDesc__gBC8z6Ez5xj3dXoP0ylCRA* result;
	result = (tyObject_PyModuleDesc__gBC8z6Ez5xj3dXoP0ylCRA*)0;
	result = (&moduleDescX60gensym3___fast_35);
	return result;
}
static N_INLINE(void, nimFrame)(TFrame* s) {
	{
		if (!(framePtr__system_2566 == ((TFrame*) NIM_NIL))) goto LA3_;
		(*s).calldepth = ((NI16) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		(*s).calldepth = (NI16)((*framePtr__system_2566).calldepth + ((NI16) 1));
	}
	LA1_: ;
	(*s).prev = framePtr__system_2566;
	framePtr__system_2566 = s;
	{
		if (!((*s).calldepth == ((NI16) 2000))) goto LA8_;
		callDepthLimitReached__system_2999();
	}
	LA8_: ;
}
static N_INLINE(void, popFrame)(void) {
	framePtr__system_2566 = (*framePtr__system_2566).prev;
}
static N_INLINE(void, updateStackBottom__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_322)(void) {
	NI volatile a;
	nimfr_("updateStackBottom", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	a = (NI)0;
	nimln_(231, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	nimGC_setStackBottom(((void*) (((NU) (ptrdiff_t) ((&a))))));
	popFrame();
}
static N_INLINE(void, pushSafePoint)(TSafePoint* s) {
	(*s).prev = excHandler__system_2567;
	excHandler__system_2567 = s;
}
static N_INLINE(void, popSafePoint)(void) {
	excHandler__system_2567 = (*excHandler__system_2567).prev;
}
static N_INLINE(TFrame*, getFrame)(void) {
	TFrame* result;
	result = (TFrame*)0;
	result = framePtr__system_2566;
	return result;
}
static N_INLINE(void, setFrame)(TFrame* s) {
	framePtr__system_2566 = s;
}
static N_INLINE(Exception*, nimBorrowCurrentException)(void) {
	Exception* result;
	nimfr_("nimBorrowCurrentException", "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system.nim");
	result = NIM_NIL;
	nimln_(2417, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system.nim");
	result = currException__system_2568;
	popFrame();
	return result;
}
static N_INLINE(Exception*, getCurrentException)(void) {
	Exception* result;
	nimfr_("getCurrentException", "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system.nim");
	result = NIM_NIL;
	nimln_(2412, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system.nim");
	result = currException__system_2568;
	popFrame();
	return result;
}
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringDesc* s) {
	NCSTRING result;
	result = (NCSTRING)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (s == ((NimStringDesc*) NIM_NIL));
		if (T3_) goto LA4_;
		T3_ = ((*s).Sup.len == ((NI) 0));
		LA4_: ;
		if (!T3_) goto LA5_;
		result = "";
	}
	goto LA1_;
	LA5_: ;
	{
		result = ((NCSTRING) ((*s).data));
	}
	LA1_: ;
	return result;
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	nimfr_("+%", "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/arithmetics.nim");
	result = (NI)0;
	nimln_(403, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/arithmetics.nim");
	nimln_(407, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/arithmetics.nim");
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	popFrame();
	return result;
}
static N_INLINE(void, incRef__system_5392)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	nimfr_("incRef", "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	nimln_(231, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
	popFrame();
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	nimfr_("-%", "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/arithmetics.nim");
	result = (NI)0;
	nimln_(414, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/arithmetics.nim");
	nimln_(418, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/arithmetics.nim");
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	popFrame();
	return result;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__system_5354)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	nimfr_("usrToCell", "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	nimln_(177, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	popFrame();
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	nimfr_("<%", "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/comparisons.nim");
	result = (NIM_BOOL)0;
	nimln_(186, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/comparisons.nim");
	nimln_(188, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/comparisons.nim");
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	popFrame();
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5397)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	nimfr_("rtlAddZCT", "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	nimln_(243, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	addZCT__system_5348((&gch__system_5301.zct), c);
	popFrame();
}
static N_INLINE(void, decRef__system_5399)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	nimfr_("decRef", "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	nimln_(248, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	nimln_(249, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		nimln_(250, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
		rtlAddZCT__system_5397(c);
	}
	LA4_: ;
	popFrame();
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	nimfr_("asgnRef", "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	nimln_(286, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__system_5354(src);
		incRef__system_5392(T5_);
	}
	LA3_: ;
	nimln_(287, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__system_5354((*dest));
		decRef__system_5399(T10_);
	}
	LA8_: ;
	nimln_(288, "/home/gm/.choosenim/toolchains/nim-1.6.6/lib/system/gc.nim");
	(*dest) = src;
	popFrame();
}
static N_INLINE(void, popCurrentException)(void) {
	asgnRef((void**) (&currException__system_2568), (*currException__system_2568).up);
}
N_LIB_PRIVATE N_NIMCALL(NI, fib__fast_75)(NI n) {
	NI result;
	NI TM__A82ybR1KJ9a3GOSp2XtOMmw_8;
	NI T9_;
	NI TM__A82ybR1KJ9a3GOSp2XtOMmw_9;
	NI T10_;
	NI TM__A82ybR1KJ9a3GOSp2XtOMmw_10;
	nimfr_("fib", "/home/gm/Dev/nym/nym/fast/fast.nim");
{	result = (NI)0;
	nimln_(5, "/home/gm/Dev/nym/nym/fast/fast.nim");
	{
		if (!(n < ((NI) 1))) goto LA3_;
		nimln_(6, "/home/gm/Dev/nym/nym/fast/fast.nim");
		result = ((NI) 0);
		goto BeforeRet_;
	}
	LA3_: ;
	nimln_(7, "/home/gm/Dev/nym/nym/fast/fast.nim");
	{
		if (!(n == ((NI) 1))) goto LA7_;
		nimln_(8, "/home/gm/Dev/nym/nym/fast/fast.nim");
		result = ((NI) 1);
		goto BeforeRet_;
	}
	LA7_: ;
	nimln_(9, "/home/gm/Dev/nym/nym/fast/fast.nim");
	if (nimSubInt(n, ((NI) 1), &TM__A82ybR1KJ9a3GOSp2XtOMmw_8)) { raiseOverflow(); };
	T9_ = (NI)0;
	T9_ = fib__fast_75((NI)(TM__A82ybR1KJ9a3GOSp2XtOMmw_8));
	if (nimSubInt(n, ((NI) 2), &TM__A82ybR1KJ9a3GOSp2XtOMmw_9)) { raiseOverflow(); };
	T10_ = (NI)0;
	T10_ = fib__fast_75((NI)(TM__A82ybR1KJ9a3GOSp2XtOMmw_9));
	if (nimAddInt(T9_, T10_, &TM__A82ybR1KJ9a3GOSp2XtOMmw_10)) { raiseOverflow(); };
	result = (NI)(TM__A82ybR1KJ9a3GOSp2XtOMmw_10);
	goto BeforeRet_;
	}BeforeRet_: ;
	popFrame();
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void*, noinline__fast_82)(void* args, void* kwargs) {
	void* result;
	NI arg0n;
	TSafePoint TM__A82ybR1KJ9a3GOSp2XtOMmw_6;
	TFrame* _nimCurFrame;
	TSafePoint TM__A82ybR1KJ9a3GOSp2XtOMmw_7;
	NI T9_;
{	_nimCurFrame = getFrame();
	result = (void*)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = verifyArgs__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_678(args, kwargs, ((NI) 1), ((NI) 1), TM__A82ybR1KJ9a3GOSp2XtOMmw_4, 1, ((NimStringDesc*) &TM__A82ybR1KJ9a3GOSp2XtOMmw_5));
		if (!!(T3_)) goto LA4_;
		result = ((void*) (NIM_NIL));
		goto BeforeRet_;
	}
	LA4_: ;
	arg0n = (NI)0;
	pushSafePoint(&TM__A82ybR1KJ9a3GOSp2XtOMmw_6);
	TM__A82ybR1KJ9a3GOSp2XtOMmw_6.status = setjmp(TM__A82ybR1KJ9a3GOSp2XtOMmw_6.context);
	if (TM__A82ybR1KJ9a3GOSp2XtOMmw_6.status == 0) {
	parseArg__fast_89(args, kwargs, ((NI) 0), "n", (&arg0n));
	popSafePoint();
	}
	else {
		popSafePoint();
		setFrame(_nimCurFrame);
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIcatchableerror__qrLSDoe2oBoAqNtJ9badtnA_))) {
			tyObject_CatchableError__qrLSDoe2oBoAqNtJ9badtnA* eX60gensym4_;
			Exception* T8_;
			TM__A82ybR1KJ9a3GOSp2XtOMmw_6.status = 0;
			T8_ = NIM_NIL;
			T8_ = getCurrentException();
			eX60gensym4_ = ((tyObject_CatchableError__qrLSDoe2oBoAqNtJ9badtnA*) (T8_));
			(*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).PyErr_SetString((*pyLib__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_279).PyExc_TypeError, nimToCStringConv((*eX60gensym4_).Sup.message));
			result = ((void*) (NIM_NIL));
			popCurrentException();
			goto BeforeRet_;
			popCurrentException();
		}
	}
	if (TM__A82ybR1KJ9a3GOSp2XtOMmw_6.status != 0) reraiseException();
	pushSafePoint(&TM__A82ybR1KJ9a3GOSp2XtOMmw_7);
	TM__A82ybR1KJ9a3GOSp2XtOMmw_7.status = setjmp(TM__A82ybR1KJ9a3GOSp2XtOMmw_7.context);
	if (TM__A82ybR1KJ9a3GOSp2XtOMmw_7.status == 0) {
	T9_ = (NI)0;
	T9_ = fib__fast_75(arg0n);
	result = nimValueOrVoidToPy__fast_102(T9_);
	popSafePoint();
	}
	else {
		popSafePoint();
		setFrame(_nimCurFrame);
		if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIexception__XEycrCsme5C8CVWAYEcdBQ_))) {
			Exception* eX60gensym5_;
			TM__A82ybR1KJ9a3GOSp2XtOMmw_7.status = 0;
			eX60gensym5_ = getCurrentException();
			result = pythonException__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_324(eX60gensym5_);
			popCurrentException();
		}
	}
	if (TM__A82ybR1KJ9a3GOSp2XtOMmw_7.status != 0) reraiseException();
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_CDECL(void*, fibPy_wrapper__fast_45)(void* selfX60gensym5_, void* args, void* kwargs) {
	void* result;
	tyProc__iv6n7tcGawU401muvntJ9cA volatile pX60gensym5_;
	nimfr_("fibPy_wrapper", "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	result = (void*)0;
	nimln_(665, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	updateStackBottom__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_322();
	nimln_(673, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	pX60gensym5_ = noinline__fast_82;
	nimln_(674, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
	result = pX60gensym5_(args, kwargs);
	popFrame();
	return result;
}
static N_INLINE(void, initStackBottomWith)(void* locals) {
	nimGC_setStackBottom(locals);
}

N_LIB_PRIVATE void PreMainInner(void) {
	stdlib_ioInit000();
	stdlib_winleanInit000();
	stdlib_timesInit000();
	stdlib_osInit000();
	nimpy_py_libInit000();
}

N_LIB_PRIVATE int cmdCount;
N_LIB_PRIVATE char** cmdLine;
N_LIB_PRIVATE char** gEnv;
N_LIB_PRIVATE void PreMain(void) {
	void (*volatile inner)(void);
	inner = PreMainInner;
	systemDatInit000();
	initStackBottomWith((void *)&inner);
	systemInit000();
	stdlib_winleanDatInit000();
	stdlib_timesDatInit000();
	stdlib_osDatInit000();
	nimpy_py_typesDatInit000();
	nimpy_py_libDatInit000();
	nimpy_nimpyDatInit000();
	(*inner)();
}

N_LIB_PRIVATE N_CDECL(void, NimMainInner)(void) {
	NimMainModule();
}

N_LIB_EXPORT N_CDECL(void, NimMain)(void) {
	void (*volatile inner)(void);
	PreMain();
	inner = NimMainInner;
	initStackBottomWith((void *)&inner);
	(*inner)();
}

BOOL WINAPI DllMain(HINSTANCE hinstDLL, DWORD fwdreason, 
                    LPVOID lpvReserved) {
	if(fwdreason == DLL_PROCESS_ATTACH) {
	NimMain();
}
	return 1;
}

N_LIB_PRIVATE N_NIMCALL(void, NimMainModule)(void) {
{
	TFrame FR_; FR_.len = 0;

	nimRegisterGlobalMarker(TM__A82ybR1KJ9a3GOSp2XtOMmw_2);

}/* preInitProc end */
{
	nimfr_("fast", "/home/gm/Dev/nym/nym/fast/fast.nim");
	{
		nimln_(328, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
		initPythonModuleDesc__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_289((&moduleDescX60gensym3___fast_35), "fast", "");
		nimln_(340, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
		registerExportedModule__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48ZnimpyZpy95lib_308(((NimStringDesc*) &TM__A82ybR1KJ9a3GOSp2XtOMmw_3), ((void*) (initfast)), ((void*) (PyInit_fast)));
	}
	{
		nimln_(346, "/home/gm/.nimble/pkgs/nimpy-0.2.0/nimpy.nim");
		curModuleDef__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_53 = _nimpyModuleDesc_fast();
	}
	nimln_(4, "/home/gm/Dev/nym/nym/fast/fast.nim");
	registerMethod__OOZOOZOOZOOZOnimbleZpkgsZnimpy4548O50O48Znimpy_63("fib", ((NCSTRING) NIM_NIL), fibPy_wrapper__fast_45);
	popFrame();
}
}

